/* <ddtmdef.h>
 *
 *	Transaction Manager services structure definitions
 */
#ifndef _DDTMDEF_H
#define _DDTMDEF_H

/* note: these first couple of items are broken in V5.5's Starlet entry */
union ddtm$r_tid {
    unsigned int ddtm$x_transaction_id[4];
    unsigned int ddtm$x_utc_date_time[4];
};
#define DDTM$S_TRANSACTION_ID	16	/* size of transaction ID type */
#define DDTM$S_UTC_DATE_TIME	16	/* size of UTC type */
#define DDTM$S_TID		16	/* size of a transaction ID */

/* system services modifier flags */
#define DDTM$V_SYNC		0
#define DDTM$V_NONDEFAULT	1
#define DDTM$V_PROCESS		2
#define DDTM$V_VOLATILE		3
#define DDTM$V_RUNDOWN		4
#define DDTM$V_CANCEL		5
#define DDTM$V_FULL_STATE	6
#define DDTM$V_BRANCH_UNSYNCHED 7
#define DDTM$V_COORDINATOR	8
#define DDTM$V_NOWAIT		9
#define DDTM$V_FINAL_STATE	10
#define DDTM$V_LATE		31
#define DDTM$M_SYNC		(1<<DDTM$V_SYNC)		/* 0x01 */
#define DDTM$M_NONDEFAULT	(1<<DDTM$V_NONDEFAULT)		/* 0x02 */
#define DDTM$M_PROCESS		(1<<DDTM$V_PROCESS)		/* 0x04 */
#define DDTM$M_VOLATILE		(1<<DDTM$V_VOLATILE)		/* 0x08 */
#define DDTM$M_RUNDOWN		(1<<DDTM$V_RUNDOWN)		/* 0x10 */
#define DDTM$M_CANCEL		(1<<DDTM$V_CANCEL)		/* 0x20 */
#define DDTM$M_FULL_STATE	(1<<DDTM$V_FULL_STATE)		/* 0x40 */
#define DDTM$M_BRANCH_UNSYNCHED (1<<DDTM$V_BRANCH_UNSYNCHED)	/* 0x80 */
#define DDTM$M_COORDINATOR	(1<<DDTM$V_COORDINATOR)		/* 0x0100 */
#define DDTM$M_NOWAIT		(1<<DDTM$V_NOWAIT)		/* 0x0200 */
#define DDTM$M_FINAL_STATE	(1<<DDTM$V_FINAL_STATE)		/* 0x0400 */
#define DDTM$M_LATE		(1<<DDTM$V_LATE)		/* 0x80000000 */
struct ddtm$r_flags {
    unsigned ddtm$v_sync	: 1;	/* synchronous status requested */
    unsigned ddtm$v_nondefault	: 1;	/* not the default transaction */
    unsigned ddtm$v_process	: 1;	/* process-permanent RM */
    unsigned ddtm$v_volatile	: 1;	/* volatile-only state */
    unsigned ddtm$v_rundown	: 1;	/* forget all RMs */
    unsigned ddtm$v_cancel	: 1;	/* cancel GET operation */
    unsigned ddtm$v_full_state	: 1;	/* full state information */
    unsigned ddtm$v_branch_unsynched : 1; /* don't need to sync branch */
    unsigned ddtm$v_coordinator : 1;	/* join Coordinating RM */
    unsigned ddtm$v_nowait	: 1;	/* don't wait for termination */
    unsigned ddtm$v_final_state : 1;	/* get final transaction outcome */
    unsigned			: 20;	/* fill out to a longword */
    unsigned ddtm$v_late	: 1;	/* phase one branch or join */
};

/* resource manager event request options */
#define DDTM$V_EV_PREPARE	0
#define DDTM$V_EV_ABORT		1
#define DDTM$V_EV_COMMIT	2
#define DDTM$V_EV_DEFAULT_TRANS 3
#define DDTM$V_EV_TRANS_START	4
#define DDTM$M_EV_PREPARE	(1<<DDTM$V_EV_PREPARE)		/* 0x01 */
#define DDTM$M_EV_ABORT		(1<<DDTM$V_EV_ABORT)		/* 0x02 */
#define DDTM$M_EV_COMMIT	(1<<DDTM$V_EV_COMMIT)		/* 0x04 */
#define DDTM$M_EV_DEFAULT_TRANS (1<<DDTM$V_EV_DEFAULT_TRANS)	/* 0x08 */
#define DDTM$M_EV_TRANS_START	(1<<DDTM$V_EV_TRANS_START)	/* 0x10 */
struct ddtm$r_event_mask {
    unsigned ddtm$v_ev_prepare	: 1;	/* vote request required */
    unsigned ddtm$v_ev_abort	: 1;	/* abort notificiation */
    unsigned ddtm$v_ev_commit	: 1;	/* commit notificiation */
    unsigned ddtm$v_ev_default_trans : 1; /* new default TID */
    unsigned ddtm$v_ev_trans_start : 1; /* request transaction start events */
    unsigned			: 27;	/* fill out to a longword */
};

/* $TRANS_EVENT system service event types */
#define DDTM$K_TX_PREPARE	1	/* prepare transaction request */
#define DDTM$K_TX_COMMIT	2	/* commit transaction order */
#define DDTM$K_TX_ABORT		3	/* abort transaction order */
#define DDTM$K_TX_RECOVER_COMMIT 4	/* commit order on recovery */
#define DDTM$K_TX_RECOVER_ABORT 5	/* abort order on recovery */

/* resource manager event report types */
#define DDTM$K_PREPARE		1	/* prepare operation */
#define DDTM$K_COMMIT		2	/* commit operation */
#define DDTM$K_ABORT		3	/* abort operation */
#define DDTM$K_ONE_PHASE_COMMIT 4	/* one-phase commit */
#define DDTM$K_DEFAULT_CLEARED	5	/* TID no longer default */
#define DDTM$K_DEFAULT_SET	6	/* TID now process default */
#define DDTM$K_STARTED_DEFAULT	7	/* new process default transaction */
#define DDTM$K_STARTED_NONDEFAULT 8	/* new nondefault transaction */
#define DDTM$K_RECOVER_COMMITTED 9	/* transaction committed */
#define DDTM$K_RECOVER_ERROR	10	/* error during recovery */
#define DDTM$K_RECOVER_INDOUBT	11	/* transaction is indoubt */
#define DDTM$K_RECOVER_RESOLVE	12	/* RM resposible for resolution */

/* rransaction report structure (DECdtm V1.0) */
struct ddtm$r_astdef {			/* transaction event AST parameter */
    unsigned long ddtm$l_arglen;	/* structure length */
    int *ddtm$a_tid;			/* transaction id */
    unsigned long ddtm$l_part_id;	/* participant identifier */
    unsigned long ddtm$l_rm_ctx;	/* RM event ASTPRM */
    unsigned long ddtm$l_optype;	/* operation type */
    unsigned long ddtm$l_reason;	/* abort extended reason code */
    unsigned int ddtm$o_utc_cmt_time[4]; /* reserved to Digital */
    unsigned int ddtm$o_utc_latest[4];	/* reserved to Digital */
};

/* transaction report structure */
struct ddtm$r_reportdef {
    unsigned long ddtm$l_report_len;	/* structure length */
    int *ddtm$a_tid_ptr;		/* transaction id */
    unsigned long ddtm$l_report_id;	/* report identifier */
    unsigned long ddtm$l_rm_context;	/* RM event ASTPRM */
    unsigned long ddtm$l_event_type;	/* event report type */
    unsigned long ddtm$l_abort_reason;	/* abort extended reason code */
    unsigned int ddtm$o_commit_time[4]; /* reserved to Digital */
    unsigned int ddtm$o_latest_time[4]; /* reserved to Digital */
    unsigned int ddtm$q_tx_class[2];	/* transaction class descriptor */
    unsigned int ddtm$q_part_name[2];	/* RM Instance descriptor */
};

#endif	/*_DDTMDEF_H*/
