/* <faldef.h>
 *
 *	Message/status codes for FAL object
 */
#ifndef _FALDEF_H
#define _FALDEF_H

/*
   Messages are for the FAL (DECnet file access listener) facility, but
   are generated on behalf of FAL by RMS.  The DAP status is translated
   into FAL status and reported as secondary status information for the
   RMS$_NETFAIL and RMS$_SUPPORT completion codes.

   Layout of message space:
	msg numbers	msg numbers	msg codes	description
	(decimal)	(hexadecimal)	(hexadecimal)
	   0 - 1023	0000 - 03FF	8000 - 9FFF	unused
	1024 - 2047	0400 - 07FF	A000 - BFFF	for RMS$_NETFAIL
	2048 - 4095	0800 - 0FFF	C000 - FFFF	for RMS$_SUPPORT
 */

#define FAL$_FACILITY	503	/* 0x01F7 */

/*
   Define FAL status codes that are associated with the RMS$_NETFAIL completion
   code and returned in the STV field of the FAB or RAB.

   Use the following formula to map a DAP status code (stscode field with
   maccode = 4 thru 7) into a corresponding FAL message code (lower 16 bits):

	message-code = (0x8000 | ((miccode | 0x400) << 3) | severity_level)


   Note:  the first three characters of the message identification mnemonic
	  for each message code in this set indicates its origin as follows:
	RMS --- the code is defined for RMS-11 or RMS-20, but not for RMS-32.
	FCS --- the code is defined for the FCS-11 environment.
	TEN --- the code is defined for the TOPS-10 environment.
	DAP --- origin in the dap specification is unknown.
 */
#define FAL$_OFFSET_A	0x0400		/* 1024 */
/* miccode = 0000 */
#define FAL$_DAPFAIL		0x01F7A004	/* 33005572 */
#define FAL$_RMSABO		0x01F7A00C	/* 33005580 */
/* miccode = 0011 */
#define FAL$_RMSAST		0x01F7A04C	/* 33005644 */
#define FAL$_RMSBPA		0x01F7A054	/* 33005652 */
#define FAL$_RMSBPS		0x01F7A05C	/* 33005660 */
/* miccode = 0026 */
#define FAL$_RMSCLS		0x01F7A0B4	/* 33005748 */
/* miccode = 0056 */
#define FAL$_RMSFID		0x01F7A174	/* 33005940 */
/* miccode = 0071 */
#define FAL$_RMSINI		0x01F7A1CC	/* 33006028 */
/* miccode = 0102 */
#define FAL$_RMSLBL		0x01F7A214	/* 33006100 */
#define FAL$_RMSLBY		0x01F7A21C	/* 33006108 */
#define FAL$_RMSLCH		0x01F7A224	/* 33006116 */
/* miccode = 0106 */
#define FAL$_RMSLOC		0x01F7A234	/* 33006132 */
#define FAL$_RMSMAP		0x01F7A23C	/* 33006140 */
/* miccode = 0115 */
#define FAL$_RMSNID		0x01F7A26C	/* 33006188 */
/* miccode = 0117 */
#define FAL$_RMSOPN		0x01F7A27C	/* 33006204 */
/* miccide = 0124 */
#define FAL$_RMSPRM		0x01F7A2A4	/* 33006244 */
/* miccode = 0153 */
#define FAL$_RMSSTK		0x01F7A35C	/* 33006428 */
/* miccode = 0162 */
#define FAL$_RMSVOL		0x01F7A394	/* 33006484 */
/* miccode = 0170 */
#define FAL$_RMSCAA		0x01F7A3C4	/* 33006532 */
/* miccode = 0231 */
#define FAL$_RMSBLK		0x01F7A4CC	/* 33006796 */
#define FAL$_RMSBSZ		0x01F7A4D4	/* 33006804 */
#define FAL$_RMSCDR		0x01F7A4DC	/* 33006812 */
#define FAL$_RMSCGJ		0x01F7A4E4	/* 33006820 */
#define FAL$_RMSCOF		0x01F7A4EC	/* 33006828 */
#define FAL$_RMSJFN		0x01F7A4F4	/* 33006836 */
#define FAL$_RMSPEF		0x01F7A4FC	/* 33006844 */
#define FAL$_RMSTRU		0x01F7A504	/* 33006852 */
#define FAL$_RMSUDF		0x01F7A50C	/* 33006860 */
#define FAL$_RMSXCL		0x01F7A514	/* 33006868 */
#define FAL$_DAPDIRFUL		0x01F7A51C	/* 33006876 */
#define FAL$_FCSHWR		0x01F7A524	/* 33006884 */
#define FAL$_FCSFHE		0x01F7A52C	/* 33006892 */
#define FAL$_DAPWRTEOF		0x01F7A534	/* 33006900 */
#define FAL$_FCSONP		0x01F7A53C	/* 33006908 */
#define FAL$_FCSDNA		0x01F7A544	/* 33006916 */
#define FAL$_FCSDAA		0x01F7A54C	/* 33006924 */
#define FAL$_FCSDUN		0x01F7A554	/* 33006932 */
#define FAL$_FCSRSU		0x01F7A55C	/* 33006940 */
#define FAL$_FCSOVR		0x01F7A564	/* 33006948 */
#define FAL$_FCSBCC		0x01F7A56C	/* 33006956 */
#define FAL$_FCSNOD		0x01F7A574	/* 33006964 */
#define FAL$_FCSIFU		0x01F7A57C	/* 33006972 */
#define FAL$_FCSHFU		0x01F7A584	/* 33006980 */
#define FAL$_FCSWAC		0x01F7A58C	/* 33006988 */
#define FAL$_FCSCKS		0x01F7A594	/* 33006996 */
#define FAL$_FCSWAT		0x01F7A59C	/* 33007004 */
#define FAL$_FCSALN		0x01F7A5A4	/* 33007012 */
#define FAL$_FCSBTF		0x01F7A5AC	/* 33007020 */
#define FAL$_FCSILL		0x01F7A5B4	/* 33007028 */
#define FAL$_FCS2DV		0x01F7A5BC	/* 33007036 */
#define FAL$_FCSFEX		0x01F7A5C4	/* 33007044 */
#define FAL$_FCSRNM		0x01F7A5CC	/* 33007052 */
#define FAL$_FCSFOP		0x01F7A5D4	/* 33007060 */
#define FAL$_FCSVER		0x01F7A5DC	/* 33007068 */
#define FAL$_FCSEOV		0x01F7A5E4	/* 33007076 */
#define FAL$_FCSDAO		0x01F7A5EC	/* 33007084 */
#define FAL$_FCSBBE		0x01F7A5F4	/* 33007092 */
#define FAL$_FCSEOT		0x01F7A5FC	/* 33007100 */
#define FAL$_FCSNBF		0x01F7A604	/* 33007108 */
#define FAL$_FCSNBK		0x01F7A60C	/* 33007116 */
#define FAL$_FCSNST		0x01F7A614	/* 33007124 */
#define FAL$_FCSULK		0x01F7A61C	/* 33007132 */
#define FAL$_FCSNLN		0x01F7A624	/* 33007140 */
#define FAL$_FCSSRE		0x01F7A62C	/* 33007148 */
/* miccode = 0311 */
#define FAL$_DAPQUOEXC		0x01F7A64C	/* 33007180 */
/* miccode = 0346 */
#define FAL$_DAPDIRCAF		0x01F7A734	/* 33007412 */
#define FAL$_DAPDIRCRA		0x01F7A73C	/* 33007420 */
#define FAL$_DAPDIRPRO		0x01F7A744	/* 33007428 */
#define FAL$_DAPDIRPRA		0x01F7A74C	/* 33007436 */
#define FAL$_DAPDIRNFA		0x01F7A754	/* 33007444 */
#define FAL$_DAPDIRCON		0x01F7A75C	/* 33007452 */
/* miccode = 0416 */
#define FAL$_TENFILMOD		0x01F7A874	/* 33007732 */
#define FAL$_TENDEVNA		0x01F7A87C	/* 33007740 */
#define FAL$_TENDEVNF		0x01F7A884	/* 33007748 */
#define FAL$_TENPARALL		0x01F7A88C	/* 33007756 */
#define FAL$_TENBNFREE		0x01F7A894	/* 33007764 */
#define FAL$_TENCSDF		0x01F7A89C	/* 33007772 */
#define FAL$_TENCDDF		0x01F7A8A4	/* 33007780 */
#define FAL$_TENSFDNF		0x01F7A8AC	/* 33007788 */
#define FAL$_TENSLE		0x01F7A8B4	/* 33007796 */
#define FAL$_TENSFDCNT		0x01F7A8BC	/* 33007804 */
#define FAL$_TENNCESL		0x01F7A8C4	/* 33007812 */
#define FAL$_TENCUPFIL		0x01F7A8CC	/* 33007820 */
#define FAL$_TENNETCAP		0x01F7A8D4	/* 33007828 */
#define FAL$_TENTSKNA		0x01F7A8DC	/* 33007836 */
#define FAL$_TENNODNF		0x01F7A8E4	/* 33007844 */
#define FAL$_TENSFDREN		0x01F7A8EC	/* 33007852 */
#define FAL$_TENCDFNDR		0x01F7A8F4	/* 33007860 */
#define FAL$_TENJCREAD		0x01F7A8FC	/* 33007868 */
#define FAL$_TENRENSFD		0x01F7A904	/* 33007876 */
#define FAL$_TENDEVDWN		0x01F7A90C	/* 33007884 */
#define FAL$_TENDEVRES		0x01F7A914	/* 33007892 */
#define FAL$_TENDEVMDA		0x01F7A91C	/* 33007900 */
#define FAL$_TENDEVALL		0x01F7A924	/* 33007908 */
#define FAL$_TENILLDM		0x01F7A92C	/* 33007916 */
#define FAL$_TENLPTPAG		0x01F7A934	/* 33007924 */
#define FAL$_TENLPTVFU		0x01F7A93C	/* 33007932 */
#define FAL$_TENLPTCHR		0x01F7A944	/* 33007940 */
#define FAL$_TENLPTRAM		0x01F7A94C	/* 33007948 */
#define FAL$_TENFILSPC		0x01F7A954	/* 33007956 */
/* miccode = 0453 */
#define FAL$_TENNSNOD		0x01F7A95C	/* 33007964 */
#define FAL$_TENANODI		0x01F7A964	/* 33007972 */
#define FAL$_TENSNODI		0x01F7A96C	/* 33007980 */
#define FAL$_TENNSDEV		0x01F7A974	/* 33007988 */
#define FAL$_TENADEVI		0x01F7A97C	/* 33007996 */
#define FAL$_TENSDEVI		0x01F7A984	/* 33008004 */
#define FAL$_TENNSDIR		0x01F7A98C	/* 33008012 */
#define FAL$_TENADIRI		0x01F7A994	/* 33008020 */
#define FAL$_TENSDIRI		0x01F7A99C	/* 33008028 */
#define FAL$_TENNSFIL		0x01F7A9A4	/* 33008036 */
#define FAL$_TENAFILI		0x01F7A9AC	/* 33008044 */
#define FAL$_TENSFILI		0x01F7A9B4	/* 33008052 */
#define FAL$_TENAFILR		0x01F7A9BC	/* 33008060 */
#define FAL$_TENSFILR		0x01F7A9C4	/* 33008068 */
/* miccode = 0475 */
#define FAL$_DTFFALSHT		0x01F7A9EC	/* 33008108 */
#define FAL$_DTFNOFIL		0x01F7A9F4	/* 33008116 */
#define FAL$_DTFNOREC		0x01F7A9FC	/* 33008124 */
#define FAL$_DTFNOTREG		0x01F7AA04	/* 33008132 */
#define FAL$_DTFOPRABO		0x01F7AA0C	/* 33008140 */
/* miccode = 0504 */
#define FAL$_DTFRDCKP		0x01F7AA24	/* 33008164 */

/*
   Define FAL status codes that are associated with the RMS$_SUPPORT completion
   code and returned in the STV field of the FAB or RAB.


   Use the following formula to map a DAP status code (stscode field with
   maccode = 2) into a corresponding FAL message code (lower 16 bits):

	message-code = (0x8000 | ((miccode | 0x800) << 3) | severity_level)

   Note:  the intent in this section is to define FAL status codes only for DAP
	fields that correspond directly to RMS control block fields used for
	input.	For other DAP fields that may be rejected by the remote FAL as
	being unsupported, the RMS$_SUP completion code is returned in the STS
	field of the FAB or RAB with an associated DAP code in the STV field.
 */
#define FAL$_OFFSET_B	0x0800		/* 2048 */
/* miccode = 0222 */
#define FAL$_ORG		0x01F7C494	/* 33014932 */
#define FAL$_RFM		0x01F7C49C	/* 33014940 */
#define FAL$_RAT		0x01F7C4A4	/* 33014948 */
#define FAL$_BLS		0x01F7C4AC	/* 33014956 */
#define FAL$_MRS		0x01F7C4B4	/* 33014964 */
#define FAL$_ALQ1		0x01F7C4BC	/* 33014972 */
#define FAL$_BKS		0x01F7C4C4	/* 33014980 */
#define FAL$_FSZ		0x01F7C4CC	/* 33014988 */
#define FAL$_MRN		0x01F7C4D4	/* 33014996 */
/* miccode = 0234 */
#define FAL$_DEQ1		0x01F7C4E4	/* 33015012 */
#define FAL$_FOP1		0x01F7C4EC	/* 33015020 */
/* miccode = 0241 */
#define FAL$_LRL		0x01F7C50C	/* 33015052 */
/* miccode = 0320 */
#define FAL$_ACCFUNC		0x01F7C684	/* 33015428 */
/* miccode = 0323 */
#define FAL$_FAC		0x01F7C69C	/* 33015452 */
#define FAL$_SHR		0x01F7C6A4	/* 33015460 */
/* miccode = 0420 */
#define FAL$_CTLFUNC		0x01F7C884	/* 33015940 */
/* miccode = 0422 */
#define FAL$_RAC		0x01F7C894	/* 33015956 */
#define FAL$_KEY		0x01F7C89C	/* 33015964 */
#define FAL$_KRF		0x01F7C8A4	/* 33015972 */
#define FAL$_ROP		0x01F7C8AC	/* 33015980 */
/* miccode = 0520 */
#define FAL$_CONFUNC		0x01F7CA84	/* 33016452 */
/* miccode = 0720 */
#define FAL$_CMPFUNC		0x01F7CE84	/* 33017476 */
#define FAL$_FOP2		0x01F7CE8C	/* 33017484 */
/* miccode = 01221 */
#define FAL$_FLG		0x01F7D48C	/* 33019020 */
#define FAL$_DFL		0x01F7D494	/* 33019028 */
#define FAL$_IFL		0x01F7D49C	/* 33019036 */
/* miccode = 01225 */
#define FAL$_POS		0x01F7D4AC	/* 33019052 */
#define FAL$_SIZ		0x01F7D4B4	/* 33019060 */
#define FAL$_REF		0x01F7D4BC	/* 33019068 */
#define FAL$_KNM		0x01F7D4C4	/* 33019076 */
#define FAL$_NUL		0x01F7D4CC	/* 33019084 */
#define FAL$_IAN		0x01F7D4D4	/* 33019092 */
#define FAL$_LAN		0x01F7D4DC	/* 33019100 */
#define FAL$_DAN		0x01F7D4E4	/* 33019108 */
#define FAL$_DTP		0x01F7D4EC	/* 33019116 */
/* miccode = 01321 */
#define FAL$_VOL		0x01F7D68C	/* 33019532 */
#define FAL$_ALN		0x01F7D694	/* 33019540 */
#define FAL$_AOP		0x01F7D69C	/* 33019548 */
#define FAL$_LOC		0x01F7D6A4	/* 33019556 */
/* miccode = 01326 */
#define FAL$_ALQ2		0x01F7D6B4	/* 33019572 */
#define FAL$_AID		0x01F7D6BC	/* 33019580 */
#define FAL$_BKZ		0x01F7D6C4	/* 33019588 */
#define FAL$_DEQ2		0x01F7D6CC	/* 33019596 */
/* miccode = 01521 */
#define FAL$_CDT		0x01F7DA8C	/* 33020556 */
#define FAL$_RDT		0x01F7DA94	/* 33020564 */
#define FAL$_EDT		0x01F7DA9C	/* 33020572 */
#define FAL$_RVN		0x01F7DAA4	/* 33020580 */
/* miccode = 01621 */
#define FAL$_OWNER		0x01F7DC8C	/* 33021068 */
#define FAL$_PROTSYS		0x01F7DC94	/* 33021076 */
#define FAL$_PROTOWN		0x01F7DC9C	/* 33021084 */
#define FAL$_PROTGRP		0x01F7DCA4	/* 33021092 */
#define FAL$_PROTWLD		0x01F7DCAC	/* 33021100 */

#endif	/*_FALDEF_H*/
